Rice area detection
===================

PyPI: https://pypi.org/project/dream_river/ ##### Now!!! We are going to
improve the precision of detection. This is just Demo version. ##
Description This is a library that contain rice cultivated area
detection tools and other geospatial tools for jupyter environment on
https://sphere.gistda.or.th/ in part of Data Cube. Thus, you needs go to
`sphere.gistda <https://sphere.gistda.or.th/>`__ and `register the
account <https://auth.sphere.gistda.or.th/auth/realms/sphere/protocol/openid-connect/registrations?client_id=frontend-iframe&redirect_uri=https%3A%2F%2Fsphere.gistda.or.th%2Fdashboard&state=b1580907-8f21-4a28-bd78-8cfa2ff9064b&response_mode=fragment&response_type=code&scope=openid&nonce=20300185-bc7b-4695-92c4-aa3159db0812&ui_locales=en>`__
to access jupyter lab environment interactively from a browser.

How to setup
------------

open CMD or Terminal

.. code:: python

   pip install dream_river

How to use
----------

-  access jupyter lab environment from
   `sphere.gistda <https://datacube.gistda.or.th/hub/login?next=%2Fhub%2F>`__

Load Packages
~~~~~~~~~~~~~

.. code:: python

   import dream_river

Develop by : Pathakorn Usaha github: https://github.com/Pathakorn40
